@@ -119,7 +119,7 @@ class Experiment:
             self.runs.add(run)  # [str(run.id_run)] = run
 
     def _repr_html_(self):
-        return f'add_experiment(name="{self.name}", n_runs={len(self.runs)}, id="{self.id_experiment}")'
+        return f'experiment(name="{self.name}", n_runs={len(self.runs)}, id="{self.id_experiment}")'
 
     def add_runs(self, **param_grid):
         # Populate param_grid
